@@ -15,7 +15,7 @@ def connect(host, port=106):
         sock.connect((host, port))
         sock.settimeout(5.0)
         
-        read(sock)
+        read(sock, get=False)
         
         return sock
     except socket.error as e:
@@ -33,10 +33,10 @@ def login(sock, username, pwd):
     check = '515'
     while check != '200':
         sock.send((f'USER {username}\n').encode())
-        check = read(sock)            
+        read(sock, get=False)
 
         sock.send((f'PASS {pwd}\n').encode())
-        check = read(sock, get=True)['header'][:3]
+        check = read(sock)['header'][:3]
         
         if check == '515':
             raise FailedLogin()
@@ -54,7 +54,7 @@ def disconnect(sock):
     
     sock.close()
 
-def read(sock, get=False, data=False):
+def read(sock, get=True, data=False):
     '''Metod that reads messages from server and returns dict containing server response
     if get parameter is set to True.
     
@@ -73,11 +73,16 @@ def read(sock, get=False, data=False):
     if not data:
         msg = sock.recv(4).decode()
         message['header'] = msg.strip()
-
+    
+        msg_len = 1
+    else:
+        msg_len = 4096
+        
     full = ''
+        
     while True:
         try:
-            msg = sock.recv(4096)
+            msg = sock.recv(msg_len)
             full += msg.decode()
             
             if full[-2:] == '\r\n':
@@ -90,6 +95,6 @@ def read(sock, get=False, data=False):
 
         except socket.timeout:
             break
-
-    if 'get':
+    
+    if get:
         return message
\ No newline at end of file
